@@ -7,7 +7,7 @@ RDF::Trine::Model - Model class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model version 0.127_03
+This document describes RDF::Trine::Model version 0.128_01
 
 =head1 METHODS
 
@@ -23,7 +23,7 @@ no warnings 'redefine';
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.127_03';
+	$VERSION	= '0.128_01';
 }
 
 use Scalar::Util qw(blessed);
@@ -161,7 +161,7 @@ sub add_hashref {
 	
 	foreach my $s (keys %$index) {
 		my $ts = ( $s =~ /^_:(.*)$/ ) ?
-		         RDF::Trine::Node::Blank->new($1) :
+					RDF::Trine::Node::Blank->new($1) :
 					RDF::Trine::Node::Resource->new($s);
 		
 		foreach my $p (keys %{ $index->{$s} }) {
@@ -235,6 +235,24 @@ sub size {
 	return $self->count_statements();
 }
 
+=item C<< etag >>
+
+If the model is based on a store that has the capability and knowledge to
+support caching, this method returns a persistent token that will remain
+consistent as long as the store's data doesn't change. This token is acceptable
+for use as an HTTP ETag.
+
+=cut
+
+sub etag {
+	my $self	= shift;
+	my $store	= $self->_store;
+	if ($store) {
+		return $store->etag;
+	}
+	return;
+}
+
 =item C<< count_statements ( $subject, $predicate, $object ) >>
 
 Returns a count of all the statements matching the specified subject,
@@ -618,6 +636,7 @@ sub bounded_description {
 		return if (not(@statements) and not(@nodes));
 		while (1) {
 			if (not(@statements)) {
+				my $l = Log::Log4perl->get_logger("rdf.trine.model");
 				return unless (scalar(@nodes));
 				my $n	= shift(@nodes);
 # 				warn "CBD handling node " . $n->sse . "\n";
@@ -627,13 +646,17 @@ sub bounded_description {
 					my @s	= grep { not($seen{$_->object->sse}) } $sts->get_all;
 # 					warn "+ " . $_->sse . "\n" for (@s);
 					push(@statements, @s);
-				} catch RDF::Trine::Error::UnimplementedError with {};
+				} catch RDF::Trine::Error::UnimplementedError with {
+					$l->debug('[model] Ignored UnimplementedError in bounded_description: ' . $_[0]->{'-text'});
+				};
 				try {
 					my $sts	= $self->get_statements( undef, undef, $n );
 					my @s	= grep { not($seen{$_->subject->sse}) and not($_->subject->equal($n)) } $sts->get_all;
 # 					warn "- " . $_->sse . "\n" for (@s);
 					push(@statements, @s);
-				} catch RDF::Trine::Error::UnimplementedError with {};
+				} catch RDF::Trine::Error::UnimplementedError with {
+					$l->debug('[model] Ignored UnimplementedError in bounded_description: ' . $_[0]->{'-text'});
+				};
 				$seen{ $n->sse }++
 			}
 			last if (scalar(@statements));
