@@ -7,7 +7,7 @@ RDF::Trine::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::Turtle version 0.127_03
+This document describes RDF::Trine::Parser::Turtle version 0.128_01
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ use Scalar::Util qw(blessed looks_like_number);
 our ($VERSION, $rdf, $xsd);
 our ($r_boolean, $r_comment, $r_decimal, $r_double, $r_integer, $r_language, $r_lcharacters, $r_line, $r_nameChar_extra, $r_nameStartChar_minus_underscore, $r_scharacters, $r_ucharacters, $r_booltest, $r_nameStartChar, $r_nameChar, $r_prefixName, $r_qname, $r_resource_test, $r_nameChar_test);
 BEGIN {
-	$VERSION				= '0.127_03';
+	$VERSION				= '0.128_01';
 	$RDF::Trine::Parser::parser_names{ 'turtle' }	= __PACKAGE__;
 	my $class										= __PACKAGE__;
 	$RDF::Trine::Parser::encodings{ $class }		= 'utf8';
@@ -211,7 +211,7 @@ sub _triple {
 		if ($o->isa('RDF::Trine::Node::Literal') and $o->has_datatype) {
 			my $value	= $o->literal_value;
 			my $dt		= $o->literal_datatype;
-			my $canon	= $self->canonicalize_literal_value( $value, $dt );
+			my $canon	= RDF::Trine::Node::Literal->canonicalize_literal_value( $value, $dt, 1 );
 			$o	= literal( $canon, undef, $dt );
 		}
 	}
