@@ -4,35 +4,14 @@ RDF::Trine::Store::DBI::mysql - Mysql subclass of DBI store
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI::mysql version 0.127_03
+This document describes RDF::Trine::Store::DBI::mysql version 0.128_01
 
 =head1 SYNOPSIS
 
     use RDF::Trine::Store::DBI::mysql;
 
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
-  
 =head1 DESCRIPTION
 
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
-
-
-=head1 DEPENDENCIES
-
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
 =cut
 
 package RDF::Trine::Store::DBI::mysql;
@@ -44,14 +23,45 @@ use base qw(RDF::Trine::Store::DBI);
 
 use Scalar::Util qw(blessed reftype refaddr);
 
-our $VERSION	= "0.127_03";
+our $VERSION;
+BEGIN {
+	$VERSION	= "0.128_01";
+	my $class	= __PACKAGE__;
+	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
+}
 
 
+sub _config_meta {
+	return {
+		required_keys	=> [qw(dsn username password name)],
+		fields			=> {
+			name		=> { description => 'Model Name', type => 'string' },
+			dsn			=> { description => 'DSN', type => 'string', template => 'DBI:mysql:database=[%database%]' },
+			database	=> { description => 'Database Name', type => 'string' },
+			username	=> { description => 'Username', type => 'string' },
+			password	=> { description => 'Password', type => 'password' },
+			driver		=> { description => 'Driver', type => 'string', value => 'mysql' },
+		},
+	}
+}
 
 =head1 METHODS
 
 =over 4
 
+=item C<< new_with_config ( \%config ) >>
+
+Returns a new RDF::Trine::Store object based on the supplied configuration hashref.
+
+=cut
+
+sub new_with_config {
+	my $proto	= shift;
+	my $config	= shift;
+	$config->{storetype}	= 'DBI::mysql';
+	return $proto->SUPER::new_with_config( $config );
+}
+
 =item C<< add_statement ( $statement [, $context] ) >>
 
 Adds the specified C<$statement> to the underlying model.
