@@ -7,7 +7,7 @@ RDF::Trine::VariableBindings - Variable bindings
 
 =head1 VERSION
 
-This document describes RDF::Trine::VariableBindings version 0.127_03
+This document describes RDF::Trine::VariableBindings version 0.128_01
 
 =head1 METHODS
 
@@ -29,7 +29,7 @@ use Scalar::Util qw(blessed refaddr);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.127_03';
+	$VERSION	= '0.128_01';
 }
 
 ######################################################################
@@ -115,7 +115,7 @@ sub join {
 		my $val_a	= $self->{ $key };
 		my $val_b	= $rowb->{ $key };
 		next unless (defined($val_a) and defined($val_b));
-		my $equal	= $val_a->equal( $val_b );
+		my $equal	= (refaddr($val_a) == refaddr($val_b)) || $val_a->equal( $val_b );
 		unless ($equal) {
 			return undef;
 		}
